@@ -20,7 +20,7 @@ int32_t SPVM__Net__SSLeay__ASN1_STRING__new(SPVM_ENV* env, SPVM_VALUE* stack) {
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
     ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
     
-    env->die_v2(env, stack, "[OpenSSL Error]ASN1_STRING_new failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
+    env->die(env, stack, "[OpenSSL Error]ASN1_STRING_new failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
     
     int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
     if (error_id) { return error_id; }
@@ -82,7 +82,7 @@ int32_t SPVM__Net__SSLeay__ASN1_STRING__set(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t len = stack[2].ival;
   
   if (!obj_data) {
-    return env->die_v2(env, stack, "The data $data must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The data $data must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const void* data = (const void*)env->get_chars(env, stack, obj_data);
@@ -97,7 +97,7 @@ int32_t SPVM__Net__SSLeay__ASN1_STRING__set(SPVM_ENV* env, SPVM_VALUE* stack) {
     char* ssl_error_string = env->get_stack_tmp_buffer(env, stack);
     ERR_error_string_n(ssl_error, ssl_error_string, SPVM_NATIVE_C_STACK_TMP_BUFFER_SIZE);
     
-    env->die_v2(env, stack, "[OpenSSL Error]ASN1_STRING_set failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
+    env->die(env, stack, "[OpenSSL Error]ASN1_STRING_set failed:%s.", __func__, FILE_NAME, __LINE__, ssl_error_string);
     
     int32_t tmp_error_id = env->get_basic_type_id_by_name(env, stack, "Net::SSLeay::Error", &error_id, __func__, FILE_NAME, __LINE__);
     if (error_id) { return error_id; }
